Discover Packages
github.com/londonhackspace/acnode-dashboard
acserver_api
package
Version:
v0.0.0-...-1eee0f7
Opens a new window with list of versions in this module.
Published: Oct 5, 2022
License: BSD-3-Clause
Opens a new window with license information.
Imports: 5
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
Documentation
¶
type ToolStatusResponse struct {
Id int `json:"id"`
Name string `json:"name"`
Status string `json:"status"`
StatusMessage string `json:"status_message"`
InUse string `json:"in_use"`
Type string `json:"type"`
MqttName string `json:"mqtt_name"`
}
type UserCardResponse struct {
Id string `json:"id"`
UserName string `json:"user_name"`
GlaDOSFile string `json:"gladosfile"`
Subscribed bool `json:"subscribed"`
}
{"user_name": "A User", "gladosfile": "", "subscribed": true, "id": "HS12345"}
type UserToolSummaryResponse struct {
Name string `json:"name"`
Status string `json:"status"`
StatusMessage string `json:"status_message"`
InUse string `json:"in_use"`
Permission string `json:"permission"`
Type string `json:"type"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.